@@ -8,10 +8,11 @@ import json
 import logging
 import pytz
 
+
 _LOGGER = logging.getLogger(__name__)
 
 
-class Stookwijzer():
+class Stookwijzer:
     """The Stookwijze API."""
 
     def __init__(self, session: aiohttp.ClientSession, x: float, y: float):
@@ -49,27 +50,51 @@ class Stookwijzer():
         return self._last_updated
 
     @staticmethod
-    async def async_transform_coordinates(
-        session: aiohttp.ClientSession, latitude: float, longitude: float
-    ):
+    async def async_transform_coordinates(latitude: float, longitude: float) -> dict | None:
         """Transform the coordinates from EPSG:4326 to EPSG:28992."""
-        url = f"https://epsg.io/srs/transform/{longitude},{latitude}.json?key=default&s_srs=4326&t_srs=28992"
-        try:
-            async with session.get(url=url, timeout=10) as response:
-                response = await response.read()
+        x0 = 155000
+        y0 = 463000
+        f0 = 52.15517440  # f => phi
+        l0 = 5.38720621  # l => lambda
 
-            coordinates = json.loads(response)
-            return coordinates["results"][0]["x"], coordinates["results"][0]["y"]
+        Rp = [0, 1, 2, 0, 1, 3, 1, 0, 2]
+        Rq = [1, 1, 1, 3, 0, 1, 3, 2, 3]
+        Rpq = [
+            190094.945,
+            -11832.228,
+            -114.221,
+            -32.391,
+            -0.705,
+            -2.34,
+            -0.608,
+            -0.008,
+            0.148,
+        ]
 
-        except aiohttp.ClientConnectorError:
-            _LOGGER.error("Error requesting coordinate conversion")
-            return None, None
-        except asyncio.TimeoutError:
-            _LOGGER.error("Timeout requesting coordinate conversion")
-            return None, None
-        except KeyError:
-            _LOGGER.error("Received invalid response transforming coordinates")
-            return None, None
+        Sp = [1, 0, 2, 1, 3, 0, 2, 1, 0, 1]
+        Sq = [0, 2, 0, 2, 0, 1, 2, 1, 4, 4]
+        Spq = [
+            309056.544,
+            3638.893,
+            73.077,
+            -157.984,
+            59.788,
+            0.433,
+            -6.439,
+            -0.032,
+            0.092,
+            -0.054,
+        ]
+
+        df = 0.36 * (latitude - f0)
+        dl = 0.36 * (longitude - l0)
+        x = x0
+        y = y0
+
+        x += sum(Rpq[i] * (df ** Rp[i]) * (dl ** Rq[i]) for i in range(9))
+        y += sum(Spq[i] * (df ** Sp[i]) * (dl ** Sq[i]) for i in range(10))
+
+        return {"x": x, "y": y}
 
     async def async_update(self) -> None:
         """Get the stookwijzer data."""
@@ -96,7 +121,9 @@ class Stookwijzer():
 
         return forecast
 
-    async def get_forecast_at_offset(self, runtime: datetime, offset: int) -> dict[str, str]:
+    async def get_forecast_at_offset(
+        self, runtime: datetime, offset: int
+    ) -> dict[str, str]:
         """Get forecast at a certain offset."""
         dt = {"datetime": (runtime + timedelta(hours=offset)).isoformat()}
         forecast = {
